# Generated by Django 4.0.2 on 2022-03-20 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_global_log", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="djangogloballog",
            name="method",
            field=models.CharField(
                blank=True, max_length=64, null=True, verbose_name="请求方法"
            ),
        ),
    ]
